# Slot: imports


other schemas that are included in this schema

URI: [http://w3id.org/biolink/biolinkml/meta/imports](slot_uri)
## Domain and Range

[SchemaDefinition](SchemaDefinition.md) -><sub>opt</sub> [[Uri](Uri.md)]
## Inheritance

## Children

## Used by

 * [SchemaDefinition](SchemaDefinition.md)
